import { BasicColumn, FormSchema } from '@/components/Table';
import { DescItem } from '@/components/Description';

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'fileName',
    width: 150,
    slots: { customRender: 'fileName' },
  },
  {
    title: '描述',
    dataIndex: 'remark',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 150,
  },
  {
    title: '权属工作组',
    dataIndex: 'workGroupName',
    width: 150,
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入名称',
    },
    colProps: { span: 7 },
  },
];
export const accountFormSchema: any[] = [
  {
    field: 'fileName',
    label: '文件名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'location',
    label: '保存位置',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'createDate',
    label: '创建时间',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'updateDate',
    label: '最近修改',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
];

/**移动*/
export const MoveFormSchema: any[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'fileName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];

export const resetNameFormSchema: FormSchema[] = [
  {
    field: 'fileName',
    label: '文件名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入文件名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件名称',
    },
    colProps: { span: 8 },
  },
];
export const createFileFormSchema: FormSchema[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'fileName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'fileName',
    label: '文件名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入文件名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件名称',
    },
  },
];
export const createTaskFormSchema: FormSchema[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'fileName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'name',
    label: '质量主体名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入质量主体名称',
      },
    ],
    componentProps: {
      placeholder: '请输入质量主体名称',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fileType',
    label: '文件类型',
    component: 'Input',
    defaultValue: '质量主体',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const formSchemaMain: any = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },

  {
    field: 'name',
    label: '主体名称',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入主体名称',
    },
  },
  {
    field: 'des',
    label: '描述',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入描述',
    },
  },
  {
    field: 'fileType',
    label: '文件类型',
    component: 'Input',
    defaultValue: '质量白名单',
    colProps: { span: 8 },
    componentProps: {
      readOnly: true,
      disabled: true,
      placeholder: '输入描述',
    },
  },
  {
    field: 'menuModal',
    label: '目录权属模式',
    component: 'Input',
    defaultValue: '资源自定义',
    colProps: { span: 8 },
    componentProps: {
      readOnly: true,
      disabled: true,
      placeholder: '输入描述',
    },
  },
  {
    field: 'group',
    label: '权属工作组',
    component: 'Select',
    defaultValue: '默认工作组',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入描述',
      options: [{ label: '默认工作组', value: '默认工作组' }],
    },
  },
];
export const basicSchema: FormSchema[] = [
  {
    field: 'name',
    label: '关联主体',
    component: 'TreeSelect',
    componentProps: {
      treeData: [
        {
          title: '质量主体',
          businessId: '1',
          parentId: '0',
          children: [
            {
              title: 'DMP_admin-个人工作区',
              businessId: '11',
              parentId: '1',
              children: [
                {
                  title: '贫困毕业生',
                  businessId: '111',
                  parentId: '11',
                },
                {
                  title: 'test',
                  businessId: '112',
                  parentId: '11',
                },
                {
                  title: 'sql_test',
                  businessId: '121',
                  parentId: '11',
                },
              ],
            },
            {
              title: '共享工作区',
              businessId: '12',
              parentId: '1',
              children: [
                {
                  title: '质量主体1',
                  businessId: '122',
                  parentId: '12',
                },
              ],
            },
          ],
        },
      ],
      fieldNames: {
        label: 'title',
        value: 'businessId',
      },
    },
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'key',
    label: '主键',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'remark',
    label: '描述',
    component: 'InputTextArea',
    colProps: { lg: 12, md: 12 },
  },
];
export const refundSchema: DescItem[] = [
  {
    field: 'dataSource',
    label: '目标数据源',
  },
  {
    field: 'dataBase',
    label: '目标数据库',
  },
];
export const storageSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名单表名',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
    required: true,
  },
];
export const partitionColumns: BasicColumn[] = [
  {
    title: 'id',
    dataIndex: 'key',
    width: 120,
  },
  {
    title: '维护人',
    dataIndex: 'user',
    width: 120,
  },
  {
    title: '名单更新时间',
    dataIndex: 'date',
    width: 120,
  },
];
export const searchTableFormSchema: FormSchema[] = [
  {
    field: 'dateBegin',
    label: '名单更新时间',
    component: 'DatePicker',
    componentProps: {},
    colProps: { span: 4 },
  },
  {
    field: 'dateEnd',
    label: '-',
    component: 'DatePicker',
    componentProps: {},
    colProps: { span: 4 },
  },
  {
    field: 'user',
    label: '维护人',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'admin',
          value: 'admin',
        },
        {
          label: 'test',
          value: 'test',
        },
        {
          label: 'test2',
          value: 'test2',
        },
      ],
    },
    labelWidth: 80,
    colProps: { span: 4 },
  },
];
export const uploadSchema: FormSchema[] = [
  {
    field: 'file',
    component: 'Upload',
    label: '上传文件',
    colProps: { lg: 24, md: 24 },
    rules: [{ required: true, message: '请选择上传文件' }],
  },
];
export const uploadColumns: BasicColumn[] = [
  {
    title: '身份标识',
    dataIndex: 'key',
    width: 120,
    align: 'left',
  },
];
